Chapter 3. CSS Class Reference

# XMLRésuméLibrary: User Guide

subjects.format | Part II. Reference | Glossary

## Chapter 3. CSS Class Reference

This section of the manual describes the Cascading Stylesheets classes that are available for formatting HTML output. For more information on CSS, visit the W3C web site.

## Overview

Table 3.1. Table of CSS Classes

Class | Where Used
--- | ---
`achievement` | On the `li` for a single achievement.
`address` | On the `p` that contains a postal address.
`award` | On the `li` for a single award.
`awardTitle` | On the `span` of an award title.
`bookTitle` | On the `cite` used to refer to a title of a book in one of your publications.
`citation` | On all HTML `cite`s generated from all XML `citation`s.
`copyright` | On the `address` for copyright information.
`degree` | On the `li` for a single degree.
`degrees` | On the `ul` for the list of degrees you hold.
`degreeTitle` | On the `span` surrounding a degree level and major, such as “B.S. in Political Science”.
`description` | Around descriptions of items.
`emphasis` | On all HTML `strong`s generated from all XML `emphasis`s.
`employer` | Around all employer names.
`gpaPreamble` | On the `span` around the preamble to a GPA, such as “Overall GPA”.
`heading` | On the `h2` of résumé section headings, such as “Professional Objective” or “Employment History”.
`headingText` | On the `span` that contains heading text. This element is contained directly within the `h2` with the `heading` class, and allows style to be applied to just the heading text, instead of the whole heading line.
`jobTitle` | On the `span` enclosing the title you held at job.
`lastModified` | On the `p` for the “last modified” notice.
`level` | On the `acronym` for the level attained in a degree.
`linkA` | On the `a` of a hyperlink generated from a `link` element in a résumé.
`membershipTitle` | On the position title in a membership.
`nameHeading` | Around your name at the top of the résumé.
`note` | On the `span` of a note.
`organization` | On the name of the organization of which you're a member.
`para` | On all HTML `p`s generated from all XML `para`s.
`project` | On the `li` for a single project.
`pub` | On a single publication.
`pubs` | On the `ul` for the list of publications.
`referee` | On the `div` of a referee.
`refereeName` | On the `div` of a referee name.
`refereeContact` | On the `div` of a referee contact.
`resume` | On the `body` of the entire HTML output.
`skill` | On the `li` for a single skill.
`skills` | If `skills.format` is `bullet`, on the `ul` for a list of skills. If `skills.format` is `comma`, on the `span` for a list of skills.
`skillsetTitle` | On the `h3` for a title of a set of skills.
`urlA` | On the `a` of a hyperlink generated from a `url` element in a résumé.

subjects.format | Part II. Reference | Glossary